==> qcad-3.15.5.3.tgz: lib/qcad/scripts/File/SaveAs/ts/SaveAs_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl_PL">
<context>
    <name>SaveAs</name>
    <message>
        <location filename="../PreferencesPage.ui" line="+17"/>
        <source>File Dialog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Use system file dialog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Saving</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Default format:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Domyślny format:</translation>
    </message>
    <message>
        <location line="+37"/>
        <source>Show warning when saving to a file format that does not support 24bit colors</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Pokaż ostrzeżenie podczas zapisywania w formacie pliku, który nie obsługuje 24bit kolory</translation>
    </message>
    <message>
        <location filename="../SaveAs.js" line="+38"/>
        <source>Load/Save</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Load / Save</translation>
    </message>
    <message>
        <source>Save as</source>
        <translatorcomment>--ignored case--
--file: qt_pl.ts--
Zapisz jako...
Zapisz jako..
Zachowaj jako...
Zachowaj jako &amp;szablon...</translatorcomment>
        <translation type="obsolete">Zachowaj jako</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+24"/>
        <source>No export filters have been found. Aborting...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+65"/>
        <source>Format:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
&amp;Format:
Format:</translatorcomment>
        <translation type="unfinished">Format:</translation>
    </message>
    <message>
        <location filename="../SaveAsInit.js" line="+2"/>
        <source>Save &amp;As...</source>
        <translatorcomment>--exact match--
--file: linguist_pl.ts--
Zapisz &amp;jako...
Zachowaj j&amp;ako...</translatorcomment>
        <translation type="unfinished">Zachowaj j&amp;ako...</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/File/SaveAs/ts/SaveAs_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>SaveAs</name>
    <message>
        <location filename="../PreferencesPage.ui" line="+17"/>
        <source>File Dialog</source>
        <translation>Okno dialogowe</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Use system file dialog</source>
        <translation>Używanie systemowego okna dialogowego</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Saving</source>
        <translation>Zapisywanie</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Default format:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Domyślny format:</translation>
    </message>
    <message>
        <location line="+37"/>
        <source>Show warning when saving to a file format that does not support 24bit colors</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Wyświetlanie ostrzeżenia podczas zapisywania pliku w formacie, który nie obsługuje 24-bitowej palety barw</translation>
    </message>
    <message>
        <source>Load/Save</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Load / Save</translation>
    </message>
    <message>
        <source>Save as</source>
        <translatorcomment>--ignored case--
--file: qt_pl.ts--
Zapisz jako...
Zapisz jako..
Zachowaj jako...
Zachowaj jako &amp;szablon...</translatorcomment>
        <translation type="obsolete">Zachowaj jako</translation>
    </message>
    <message>
        <location filename="../SaveAs.js" line="+38"/>
        <source>File</source>
        <translation>Plik</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Open/Save</source>
        <translation>Otwieranie/zapisywanie</translation>
    </message>
    <message>
        <location line="+25"/>
        <source>No export filters have been found. Aborting...</source>
        <translation>Nie odnaleziono filtrów eksportowania. Anulowanie...</translation>
    </message>
    <message>
        <location line="+74"/>
        <source>Format:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
&amp;Format:
Format:</translatorcomment>
        <translation>Format:</translation>
    </message>
    <message>
        <location filename="../SaveAsInit.js" line="+2"/>
        <source>Save &amp;As...</source>
        <translatorcomment>--exact match--
--file: linguist_pl.ts--
Zapisz &amp;jako...
Zachowaj j&amp;ako...</translatorcomment>
        <translation>Zapisz j&amp;ako...</translation>
    </message>
</context>
</TS>
